@@ -40,7 +40,7 @@ class GELFHandler(DatagramHandler):
         return traceback.format_exc(exc_info) if exc_info else ''
 
     def make_message_dict(self, record):
-        d = {
+        return self.add_extra_fields({
             'version': "1.0",
             'host': socket.gethostname(),
             'short_message': record.getMessage(),
@@ -53,11 +53,30 @@ class GELFHandler(DatagramHandler):
             '_function': record.funcName,
             '_pid': record.process,
             '_thread_name': record.threadName,
-        }
+        }, record)
+
+    def add_extra_fields(self, message_dict, record):
         # record.processName was added in Python 2.6.2
-        if hasattr(record, 'processName'):
-            d['_process_name'] = record.processName
-        return d
+        pn = getattr(record, 'processName', None)
+        if pn is not None:
+            message_dict['_process_name'] = pn
+
+        # skip_list is used to filter additional fields in a log message.
+        # It contains all attributes listed in
+        # http://docs.python.org/library/logging.html#logrecord-attributes
+        # plus exc_text, which is only found in the logging module source,
+        # and id, which is prohibited by the GELF format.
+        skip_list = (
+            'args', 'asctime', 'created', 'exc_info',  'exc_text', 'filename',
+            'funcName', 'id', 'levelname', 'levelno', 'lineno', 'module',
+            'msecs', 'msecs', 'message', 'msg', 'name', 'pathname', 'process',
+            'processName', 'relativeCreated', 'thread', 'threadName')
+
+        for key, value in record.__dict__.items():
+            if key not in skip_list and not key.startswith('_'):
+                message_dict['_%s' % key] = value
+
+        return message_dict
 
 
 class ChunkedGELF(object):
